==> otyacraftengine-fabric-3.3.0-pre.3-sources.jar: dev/felnull/otyacraftengine/client/event/OEClientEventHooks.java <==
package dev.felnull.otyacraftengine.client.event;

import dev.architectury.event.EventResult;
import dev.felnull.otyacraftengine.client.event.ClientEvent.HandRenderSelectionWrapper;
import java.util.concurrent.atomic.AtomicReference;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_638;
import net.minecraft.class_746;
import net.minecraft.class_809;
import net.minecraft.class_989;

public class OEClientEventHooks {
    public static void onLevelUnload(class_638 level) {
        MoreClientLifecycleEvents.CLIENT_LEVEL_UNLOAD.invoker().act(level);
    }

    public static boolean onRenderHand(class_4587 poseStack, class_4597 multiBufferSource, class_1268 hand, int packedLight, float partialTicks, float interpolatedPitch, float swingProgress, float equipProgress, class_1799 stack) {
        return !MoreRenderEvent.RENDER_ITEM_IN_HAND.invoker().renderItemInHand(poseStack, multiBufferSource, hand, packedLight, partialTicks, interpolatedPitch, swingProgress, equipProgress, stack).isFalse();
    }

    public static boolean onRenderArmWithItem(class_989<? extends class_1309, ? extends class_583<?>> layer, class_1309 livingEntity, class_1799 itemStack, class_809.class_811 transformType, class_1306 humanoidArm, class_4587 poseStack, class_4597 multiBufferSource, int i) {
        var event = MoreRenderEvent.RENDER_ARM_WITH_ITEM.invoker().renderArmWithItem(layer, livingEntity, itemStack, transformType, humanoidArm, poseStack, multiBufferSource, i);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onChangeHandHeight(class_1268 hand, class_1799 oldStack, class_1799 newStack) {
        var event = ClientEvent.CHANGE_HAND_HEIGHT.invoker().changeHandHeight(hand, oldStack, newStack);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onPoseHumanoidArm(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        var event = ClientEvent.POSE_HUMANOID_ARM.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
        return event.isEmpty() || event.isTrue();
    }

    public static void onPoseHumanoidArmPost(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        ClientEvent.POSE_HUMANOID_ARM_POST.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
    }

    public static void onIntegratedServerPauseChange(boolean paused) {
        ClientEvent.INTEGRATED_SERVER_PAUSE.invoker().onPauseChange(paused);
    }

    public static boolean onHandAttack(class_1799 itemStack) {
        var event = ClientEvent.HAND_ATTACK.invoker().onHandAttack(itemStack);
        return event.isEmpty() || event.isTrue();
    }

    public static ClientEvent.HandRenderSelectionWrapper onEvaluateWhichHandsToRender(ClientEvent.HandRenderSelectionWrapper handRenderSelection, class_746 player) {
        AtomicReference<ClientEvent.HandRenderSelectionWrapper> wrapperAtomicReference = new AtomicReference<>();
        ClientEvent.EVALUATE_RENDER_HANDS.invoker().onEvaluateRenderHands(handRenderSelection, player, wrapperAtomicReference::set);
        var ret = wrapperAtomicReference.get();
        return ret != null ? ret : handRenderSelection;
    }

    public static boolean onCheckTextureURL(String url) {
        return TextureEvent.CHECK_TEXTURE_URL.invoker().onCheckURL(url).isTrue();
    }

    public static String onSwapTextureURL(String url) {
        String[] nurl = {url};
        TextureEvent.SWAP_TEXTURE_URL.invoker().onSwapURL(url, new TextureEvent.TextureURLSwapper() {
            @Override
            public void setURL(String url) {
                nurl[0] = url;
            }

            @Override
            public String getURL() {
                return nurl[0];
            }
        });
        return nurl[0];
    }
}

==> otyacraftengine-fabric-3.5.0-pre.24-sources.jar: dev/felnull/otyacraftengine/client/event/OEClientEventHooks.java <==
package dev.felnull.otyacraftengine.client.event;

import dev.architectury.event.EventResult;
import dev.felnull.otyacraftengine.client.event.ClientEvent.HandRenderSelectionWrapper;
import java.util.concurrent.atomic.AtomicReference;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_4184;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5636;
import net.minecraft.class_572;
import net.minecraft.class_583;
import net.minecraft.class_638;
import net.minecraft.class_6854;
import net.minecraft.class_746;
import net.minecraft.class_758;
import net.minecraft.class_809;
import net.minecraft.class_989;

public class OEClientEventHooks {
    public static void onLevelUnload(class_638 level) {
        MoreClientLifecycleEvents.CLIENT_LEVEL_UNLOAD.invoker().act(level);
    }

    public static boolean onRenderHand(class_4587 poseStack, class_4597 multiBufferSource, class_1268 hand, int packedLight, float partialTicks, float interpolatedPitch, float swingProgress, float equipProgress, class_1799 stack) {
        return !MoreRenderEvent.RENDER_ITEM_IN_HAND.invoker().renderItemInHand(poseStack, multiBufferSource, hand, packedLight, partialTicks, interpolatedPitch, swingProgress, equipProgress, stack).isFalse();
    }

    public static boolean onRenderArmWithItem(class_989<? extends class_1309, ? extends class_583<?>> layer, class_1309 livingEntity, class_1799 itemStack, class_809.class_811 transformType, class_1306 humanoidArm, class_4587 poseStack, class_4597 multiBufferSource, int i) {
        var event = MoreRenderEvent.RENDER_ARM_WITH_ITEM.invoker().renderArmWithItem(layer, livingEntity, itemStack, transformType, humanoidArm, poseStack, multiBufferSource, i);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onChangeHandHeight(class_1268 hand, class_1799 oldStack, class_1799 newStack) {
        var event = ClientEvent.CHANGE_HAND_HEIGHT.invoker().changeHandHeight(hand, oldStack, newStack);
        return event.isEmpty() || event.isTrue();
    }

    public static boolean onPoseHumanoidArm(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        var event = ClientEvent.POSE_HUMANOID_ARM.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
        return event.isEmpty() || event.isTrue();
    }

    public static void onPoseHumanoidArmPost(class_1306 arm, class_1268 hand, class_572<? extends class_1309> model, class_1309 livingEntity) {
        ClientEvent.POSE_HUMANOID_ARM_POST.invoker().poseHumanoidArm(arm, hand, model, livingEntity);
    }

    public static void onIntegratedServerPauseChange(boolean paused) {
        ClientEvent.INTEGRATED_SERVER_PAUSE.invoker().onPauseChange(paused);
    }

    public static boolean onHandAttack(class_1799 itemStack) {
        var event = ClientEvent.HAND_ATTACK.invoker().onHandAttack(itemStack);
        return event.isEmpty() || event.isTrue();
    }

    public static ClientEvent.HandRenderSelectionWrapper onEvaluateWhichHandsToRender(ClientEvent.HandRenderSelectionWrapper handRenderSelection, class_746 player) {
        AtomicReference<ClientEvent.HandRenderSelectionWrapper> wrapperAtomicReference = new AtomicReference<>();
        ClientEvent.EVALUATE_RENDER_HANDS.invoker().onEvaluateRenderHands(handRenderSelection, player, wrapperAtomicReference::set);
        var ret = wrapperAtomicReference.get();
        return ret != null ? ret : handRenderSelection;
    }

    public static boolean onCheckTextureURL(String url) {
        return TextureEvent.CHECK_TEXTURE_URL.invoker().onCheckURL(url).isTrue();
    }

    public static String onSwapTextureURL(String url) {
        String[] nurl = {url};
        TextureEvent.SWAP_TEXTURE_URL.invoker().onSwapURL(url, new TextureEvent.TextureURLSwapper() {
            @Override
            public void setURL(String url) {
                nurl[0] = url;
            }

            @Override
            public String getURL() {
                return nurl[0];
            }
        });
        return nurl[0];
    }

    public static boolean onRenderFog(class_4184 camera, class_758.class_4596 fogMode, class_5636 fogType, float startDistance, float endDistance, class_6854 fogShape, double delta, ClientCameraEvent.RenderFogSetter setter) {
        var event = ClientCameraEvent.RENDER_FOG.invoker().onRenderFog(camera, fogMode, fogType, startDistance, endDistance, fogShape, delta, setter);
        return event.isEmpty() || event.isTrue();
    }

    public static void onComputeFogColor(class_4184 camera, float red, float green, float blue, double delta, ClientCameraEvent.FogColorSetter fogColorSetter) {
        ClientCameraEvent.COMPUTE_FOG_COLOR.invoker().onComputeFogColor(camera, red, green, blue, delta, fogColorSetter);
    }
}
